package vo

import "gitea.cdlsxd.cn/BaseSystem/plugin/proto"

// QueryStatus
// INIT: 初始态。 系统转账校验中
// WAIT_PAY: 待确认。待商户确认, 符合免密条件时, 系统会自动扭转为转账中
// PROCESSING:转账中。正在处理中，转账结果尚未明确
// SUCCESS:转账成功
// FAIL:转账失败。需要确认失败原因后，再决定是否重新发起对该笔明细单的转账（并非整个转账批次单）
type QueryStatus string

const (
	QueryStatusInit       = "INIT"
	QueryStatusWaitPay    = "WAIT_PAY"
	QueryStatusProcessing = "PROCESSING"
	QueryStatusSuccess    = "SUCCESS"
	QueryStatusFail       = "FAIL"
)

var queryStatusTextMap = map[QueryStatus]string{
	QueryStatusInit:       "初始态。 系统转账校验中",
	QueryStatusWaitPay:    "待确认。待商户确认, 符合免密条件时, 系统会自动扭转为转账中",
	QueryStatusProcessing: "转账中。正在处理中，转账结果尚未明确",
	QueryStatusSuccess:    "转账成功",
	QueryStatusFail:       "转账失败。需要确认失败原因后，再决定是否重新发起对该笔明细单的转账（并非整个转账批次单）",
}

var queryStatusMap = map[QueryStatus]proto.Status{
	QueryStatusInit:       proto.Status_ING,
	QueryStatusWaitPay:    proto.Status_ING,
	QueryStatusProcessing: proto.Status_ING,
	QueryStatusSuccess:    proto.Status_SUCCESS,
	QueryStatusFail:       proto.Status_FAIL,
}

func (o QueryStatus) GetText() string {
	msg, ok := queryStatusTextMap[o]
	if !ok {
		return ""
	}
	return msg
}

func (o QueryStatus) GetOrderStatus() proto.Status {
	if o == "" {
		return proto.Status_INVALID
	}
	if resultStatus, ok := queryStatusMap[o]; ok {
		return resultStatus
	}
	return proto.Status_FAIL
}
